==> pdInfoBuilder_1.6.0.tar.gz: pdInfoBuilder/R/chipName-methods.R <==
setMethod("chipName", "AffySNPPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffySNPCNVPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

## modified by Matt Settles June 2,2008
#setMethod("chipName", "NgsPDInfoPkgSeed",
#          function(object) {
#            strsplit(tolower(object@ndfFile), ".ndf")[[1]]
#          })

## modified by Matt Settles June 2,2008
setMethod("chipName", "NgsExpressionPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the Pair file
              header <- readPairHeader(object@pairFile)
              header$DesignName
          })

## modified by Matt Settles June 2,2008
setMethod("chipName", "NgsTilingPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the Pair file
              header <- readPairHeader(object@pairFile)
              header$DesignName
          })

setMethod("chipName", "AffyExpressionPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffyTilingPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
            strsplit(tolower(object@bpmapFile), ".bpmap")[[1]]
          })

setMethod("chipName", "AffyGenePDInfoPkgSeed",
          function(object) {
              ## compute chip name from the PGF file
            readPgfEnv(object@pgfFile, readBody = FALSE)$header$lib_set_name
          })

==> pdInfoBuilder_1.8.1.tar.gz: pdInfoBuilder/R/chipName-methods.R <==
########## Affymetrix Arrays ###########
setMethod("chipName", "AffySNPPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffySNPCNVPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffySNPPDInfoPkgSeed2",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffySNPCNVPDInfoPkgSeed2",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffyExpressionPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              header <- readCdfHeader(object@cdfFile)
              header$chiptype
          })

setMethod("chipName", "AffyTilingPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the CDF file
              readCelHeader(object@celFile)$chiptype
          })
  
setMethod("chipName", "AffySTPDInfoPkgSeed",
          function(object) {
              ## compute chip name from the PGF file
              readPgfHeader(object@pgfFile)$header$chip_type[[1]]
          })

############ Nimblegen Arrays #############

setMethod("chipName", "NimbleGenPDInfoPkgSeed",
        function(object) {
          if ("pairFile" %in% slotNames(object))
            if(nchar(slot(object, "pairFile"))> 0)
                return(readPairHeader(object@pairFile)[["DesignName"]])
          return(strsplit(tolower(basename(object@ndfFile)), ".ndf")[[1]])
        })
